
# chargement_captage_prioritaire_protection_action

# librairies ----------
library(tidyverse)
library(sf)
library(mefa4)
library(lubridate)
library(mapview)
library(units)

rm(list=ls())


# communes ----------
n_bdt_commune_s_r52 <- importer_data(db = "referentiels",
                                     schema = "bdtopo_v3",
                                     table = "n_bdt_commune_s_r52") %>% 
  select(code_insee, nom_com = nom_officiel) %>% 
  mutate(surf_calculee_en_m2 = st_area(the_geom))
  

# stations, captages eau potable, captages prioritaires ------------
station <- importer_data(db = "si_eau",
                         schema = "stations",
                         table = "station")

captage_eau_potable_ars<-importer_data(db = "si_eau",
                                       schema = "stations",
                                       table = "captage_eau_potable_ars")
captage_eau_potable_ars<-right_join(station %>%
                                      select(code_station),
                                    captage_eau_potable_ars,
                                    by=c("code_station"="ins_code_national"))

station_captage_prioritaire<-importer_data(db = "si_eau",
                                           schema = "stations",
                                           table = "r_station_captage_prioritaire_r52") %>% 
  select(code_station) %>% 
  mutate(code_station = as.character(code_station))

station_captage_prioritaire$code_station<- str_pad(station_captage_prioritaire$code_station, width = 9, pad = "0", side = "left")


# protection des captages --------------
r_ppcaptages_s_r52 <- importer_data(db = "si_eau",
                                    schema = "eau_potable",
                                    table = "r_ppcaptages_s_r52") # 878 obs
protection_captage <- summarise(st_buffer(r_ppcaptages_s_r52, 0), do_union = TRUE)


# captages prioritaires et plan d'actions ---------
# selon srnp_dema courriel du 04/02/2021, les captages prioritaires ne possédant pas de Plan d'actions sont :
# pour le 49 : la Rucette (049000394) ;le Longeron ;le Prieuré de la Madeleine (049000211) ;le Puits de la Fontaine Bourreau (049000479) ;
# pour le 85 : Sainte Germaine (085000184)
# le longeron est une ancienne commune, maintenant Sèvremoine
# en fait Barrage des rivières (049000402) http://www.maine-et-loire.gouv.fr/les-captages-prioritaires-grenelle-a6180.html

station_captage_prioritaire <- left_join(station_captage_prioritaire,
                                         station %>%
                                           st_drop_geometry() %>% 
                                           select(code_station,libelle_station)) %>% 
  mutate(plan_action = ifelse(code_station %notin% c("049000394","049000402","049000211","049000479","085000184"), "oui", "non"))


# intersection captages prioritaires et communes ---------                                       
intersection_captage_prioritaire_commune <- st_intersection(station_captage_prioritaire,
                                                            st_buffer(n_bdt_commune_s_r52, 0)) %>% 
  st_drop_geometry() %>% 
  group_by(code_insee) %>% 
  mutate(nbre_captages_prioritaires = n()) %>% 
  ungroup() %>%
  select(code_insee, nbre_captages_prioritaires) %>% 
  unique() %>% 
  right_join(n_bdt_commune_s_r52 %>% 
               select(code_insee) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires = ifelse(is.na(nbre_captages_prioritaires), 0,  nbre_captages_prioritaires),
         date = today()) 


# intersection captages prioritaires bénéficiant d'un plan d'actions et territoires -----------
plan_action_commune <- st_intersection(station_captage_prioritaire,
                                       st_buffer(n_bdt_commune_s_r52, 0)) %>% 
  st_drop_geometry() %>%
  filter(plan_action ==  "oui") %>% 
  group_by(code_insee) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions = n()) %>% 
  ungroup() %>%
  select(code_insee, nbre_captages_prioritaires_avec_plan_actions) %>% 
  unique() %>% 
  right_join(n_bdt_commune_s_r52 %>% 
               select(code_insee) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions = ifelse(is.na(nbre_captages_prioritaires_avec_plan_actions), 0, nbre_captages_prioritaires_avec_plan_actions),
         date = today())


# intersections captages et protections (ppe ou ppi_ppr) ---------
captage_protege <- st_intersection(protection_captage, captage_eau_potable_ars)


# intersection captages protégés et communes ------
intersection_captage_protege_commune <- st_intersection(captage_protege,
                                                        st_buffer(n_bdt_commune_s_r52, 0)) %>% 
  st_drop_geometry() %>% 
  group_by(code_insee) %>% 
  mutate(nbre_captages_proteges = n()) %>% 
  ungroup() %>%
  select(code_insee, nbre_captages_proteges) %>% 
  unique() %>% 
  right_join(n_bdt_commune_s_r52 %>% 
               select(code_insee) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_proteges = ifelse(is.na(nbre_captages_proteges), 0, nbre_captages_proteges),
         date = today())


# assemblage captages ------------
captage_prioritaire_protection_action_1 <- intersection_captage_prioritaire_commune %>%
  select(code_insee, date, nbre_captages_prioritaires) %>% 
  left_join(plan_action_commune) %>% 
  left_join(intersection_captage_protege_commune) %>% 
  rename(depcom = code_insee)


# intersection protection et communes ----------
intersection_protection_captage_commune <- st_intersection(st_buffer(protection_captage, 0),
                                                           st_buffer(n_bdt_commune_s_r52, 0)) %>% 
  mutate(surf_protection_captage = st_area(geom))

captage_prioritaire_protection_action_2 <- intersection_protection_captage_commune %>%
  st_drop_geometry() %>% 
  right_join(n_bdt_commune_s_r52 %>% 
               select(code_insee, surf_calculee_en_m2) %>%
               st_drop_geometry()) %>% 
  mutate(surf_protection_captage = ifelse(is.na(surf_protection_captage), 0, surf_protection_captage)) %>% 
  rename(depcom = code_insee) %>% 
  select(-nom_com) %>% 
  mutate(date = today())


# assemblage captages et protection ---------
captage_prioritaire_protection_action <-full_join(captage_prioritaire_protection_action_1,
                                                  captage_prioritaire_protection_action_2)

captage_prioritaire_protection_action$surf_calculee_en_m2 <- drop_units(captage_prioritaire_protection_action$surf_calculee_en_m2)

# chargement de la liste des depcom couverts par la source
# pour obtenir tous les levels de DEPCOM (périmètre de la région seule)
source("R/levels_facteurs_com.R")

captage_prioritaire_protection_action <- captage_prioritaire_protection_action %>% 
  pivot_longer(cols = nbre_captages_prioritaires:surf_protection_captage, names_to = "variable", values_to = "valeur") %>%  
  mutate_if(is_character, as.factor) %>%
  mutate(depcom = fct_expand(depcom, com_reg)) %>%
  complete(depcom, date, variable, fill = list(valeur = 0)) %>%
  mutate(depcom = fct_expand(depcom, com_reg_et_vois)) %>%
  complete(depcom, date, variable, fill = list(valeur = NA)) %>% 
  arrange(date, depcom) %>%
  pivot_wider(names_from = variable, values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires et metdonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(df = captage_prioritaire_protection_action ,
                     nom_table_sgbd = "source_captage_prioritaire_protection_action", 
                     comm_source_en_plus = "")

