
# chargement_conso_gaz

# consommation gaz art 179 ltecv fournies par le SDES

# on récupère les données préalablement nettoyées dans le cadre du POC ENR TEO dans le SGBD
# script de nettoyage : https://gitlab-forge.din.developpement-durable.gouv.fr/dreal-pdl/csd/enr_reseaux_teo/-/tree/dev/collecte/conso_gaz
# initialement fournies par https://www.statistiques.developpement-durable.gouv.fr/donnees-locales-de-consommation-denergie 

# librairies -----------
library(dplyr)
library(tidyr)
library(forcats)
library(stringr)
library(readr)
library(purrr)
library(COGiter)
library(lubridate)
library(datalibaba)
library(googlesheets4)

rm(list=ls())


# paramètres ---------
mill <- 2022
sgbd <- FALSE

if(sgbd) {
  adr_enr_teo <- ""
} else {
  adr_enr_teo <- "C:/Users/juliette.engelaere/Documents/Travail/R_local/enr_reseaux_teo/"
  # ne fonctionne que sur le poste de JEL si sgbd <- FALSE
}


# lecture des données versées dans le sgbd dans le cadre du POC ENR TEO --------
if (sgbd) {
  
  conso_gaz_179_0 <- importer_data(table = paste0("conso_gaz_2008_", mill, "_frce_entiere"), 
                                    schema = "mecc_gaz", db = "production")
  

} else {
  load(paste0(adr_enr_teo, "collecte/sgbd/conso_gaz_2008-", mill, "_Frce_entiere.RData"))
  conso_gaz_179_0 <- compil_tot %>% 
    rename_all(tolower) %>% 
    mutate(annee = as.character(annee))
}


# début dataprep ---------
conso_gaz_179_1 <- conso_gaz_179_0 %>% 
  filter(!grepl("ZZZ", id_ter), echelle != "iris") %>%  # la table contient les com insulaires hors epci, id_ter de type ZZZZ12345
  # résolution des problèmes d'encodage
  mutate(echelle = case_when(echelle == "commune" ~ grep("com", levels(liste_zone$TypeZone), value = T, ignore.case = T),
                             echelle == "département" ~ grep("d.p", levels(liste_zone$TypeZone), value = T, ignore.case = T),
                             echelle == "région" ~ grep("r.g", levels(liste_zone$TypeZone), value = T, ignore.case = T),
                             echelle == "epci" ~ grep("epci", levels(liste_zone$TypeZone), value = T, ignore.case = T),
                             T ~ as.character(echelle)) %>% as.factor())

# commentaires sur dessin fichiers ---------
# Le df conso_gaz_179 comprend les consommations de gaz annuelles à toutes les échelles sauf iris depuis 2008.
# Il correspond à la mise aux référentiels géographiques actuels de l'ensemble de la source *consommations gaz art 179* publiée par le SDES. 
# En raison de la manière de gérer le secret, il ne faut pas utiliser les consommations communales ou à l'iris pour déduire les consommations supra, 
# mais utiliser directement les consommations agrégées à l'échelle EPCI, département ou région. Les conso Fce peuvent être calculées par somme des régions


# ajout totaux France ----------
source("R/aggreg_non_sommable/aggreg_conso_179.R")

conso_gaz_179_frmetro <- filter(conso_gaz_179_1, echelle == grep("r.g", levels(liste_zone$TypeZone), value = T, ignore.case = T),
                                !(id_ter %in% c("01", "02", "03", "04", "05", "06"))) %>%
  group_by(annee) %>%
  aggr_ter_conso() %>%
  mutate(echelle="France", id_ter="FRMETRO", lib_ter="France métropolitaine", sel_reg = FALSE)

conso_gaz_179_frentiere <- filter(conso_gaz_179_1, echelle == grep("r.g", levels(liste_zone$TypeZone), value = T, ignore.case = T)) %>%
  group_by(annee) %>%
  aggr_ter_conso() %>%
  mutate(echelle="France", id_ter="FRMETRODROM", lib_ter="France métropolitaine et DROM", sel_reg = FALSE)


conso_gaz_179_2 <- bind_rows(conso_gaz_179_1, conso_gaz_179_frmetro, conso_gaz_179_frentiere) %>% 
  mutate(date = make_date(annee, 12,31)) %>%
  mutate_if(is.character, as.factor)

# rm(conso_gaz_179_frentiere, conso_gaz_179_frmetro)


# gestion du champ 'sources' à part --------
# on isole les métadonnées dans un RData à part
# en raison d'un pb de transfert des champ de type liste dans le sgbd, on repart ici du RData

metad_conso_gaz_179 <- conso_gaz_179_2  %>%
  select(TypeZone=echelle, Zone=lib_ter, CodeZone=id_ter, date, sce_estim, sources, -annee)

save(metad_conso_gaz_179, file="metadata/metad_conso_gaz_179.RData")

# rm(metad_conso_gaz_179)


# recomposition du RData à partir du fichier SGBD -----------
# avant de passer au format long, le résultat doit ressembler à ce que produit cogifier
levels_communes <- select(communes, CodeZone = DEPCOM, Zone = NOM_DEPCOM) %>% 
  mutate_if(is.factor, as.character) %>% 
  mutate(TypeZone = grep("com", levels(liste_zone$TypeZone), value = T, ignore.case = T)) %>% 
  unite(id_zone, CodeZone, TypeZone, Zone, sep="__") %>%
  pull

conso_gaz_179 <- conso_gaz_179_2 %>%
  rename(TypeZone = echelle, Zone = lib_ter, CodeZone = id_ter, conso_gaz_gwh = conso_gwh) %>%
  rename_with( ~ gsub("na$","_gaz.inconnu", .x)) %>%            
  rename_with( ~ gsub("a$","_gaz.agriculture", .x)) %>%
  rename_with( ~ gsub("i$","_gaz.industrie", .x)) %>%
  rename_with( ~ gsub("t$","_gaz.tertiaire", .x)) %>%            
  rename_with( ~ gsub("r$","_gaz.residentiel", .x)) %>%           
  unite(id_zone, CodeZone, TypeZone, Zone, sep="__") %>%
  pivot_longer(names_to = "variable", values_to = "valeur", 'conso_gaz.agriculture':conso_gaz_gwh) %>%
  mutate(id_zone = fct_expand(id_zone, levels_communes)) %>% 
  complete(id_zone, date, variable, fill = list(valeur = NA)) %>%
  separate(id_zone, c("CodeZone", "TypeZone", "Zone"), sep="__") %>%
  select(date,  CodeZone, TypeZone, Zone, variable, valeur) %>%
  mutate_if(is.factor, as.character) %>% 
  pivot_wider(names_from = variable, values_from = valeur)

# versement et documentation dans le sgbd/datamart.portrait_territoires -------------

source("R/poster_documenter_ind.R", encoding = "UTF-8")
poster_documenter_ind(df = conso_gaz_179,
                      nom_table_sgbd = "cogifiee_conso_gaz_179", 
                      comm_source_en_plus = "T\u00e9l\u00e9chargement depuis DIDO https://www.statistiques.developpement-durable.gouv.fr/donnees-locales-de-consommation-denergie#gaz")




rm(list=ls())
