
# chargement_lgt_rgp_insee

# librairies -----------
library(dplyr)
library(tidyr)
library(purrr)
library(lubridate)
library(readxl)
library(xlsx)
library(readODS)
library(forcats)
library(stringr)

rm(list=ls())


# chargement des données logement du dernier recensement INSEE ----------

# doc INSEE disponible à https://www.insee.fr/fr/statistiques/7631186?sommaire=7631713
# Logement en 2020 - Recensement de la population - Base des principaux indicateurs

# paramètres à saisir
url <- "https://www.insee.fr/fr/statistiques/fichier/7631186/base-cc-logement-2020_xlsx.zip"
mil <- c(2020, 2014, 2009) # mettre le millesime le plus récent en premier
mil_court <- substr(mil, 3,4)
fic <- "base-cc-logement-2020"

# préfixe des variables à enlever (indique le millésime)
var_mil <- paste0("P", mil_court,"_")
var_mil_comp <- paste0("C", mil_court,"_")

# téléchargement et dézipage 
download.file(url, destfile = "extdata/lgt_RGP_INSEE.zip")
unzip("extdata/lgt_RGP_INSEE.zip", exdir="extdata")


# lecture du fichier -----------
lgt_rp_actu <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet = paste0("COM_", mil[1]), skip = 5) %>%
  mutate(annee = as.character(mil[1])) %>%
  rename_with(~sub(paste0("^", var_mil[1]), "", .x)) %>% 
  rename_with(~sub(paste0("^", var_mil_comp[1]), "", .x))

lgt_rp_old <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet =paste0("COM_", mil[2]), skip = 5) %>%
  mutate(annee = as.character(mil[2])) %>%
  rename_with(~sub(paste0("^", var_mil[2]), "", .x)) %>% 
  rename_with(~sub(paste0("^", var_mil_comp[2]), "", .x))

lgt_rp_very_old <- read_xlsx(path = paste0("extdata/", fic,".xlsx"), sheet = paste0("COM_", mil[3]), skip = 5) %>%
  mutate(annee = as.character(mil[3])) %>%
  rename_with(~sub(paste0("^", var_mil[3]), "", .x)) %>% 
  rename_with(~sub(paste0("^", var_mil_comp[3]), "", .x))


# renommage des libellés de variables grâce à une table de passage construite sous calc ------
# A adapter chaque année !!
lib_var <- read_ods(path = "metadata/Insee_RGP_lgt_lib_variable.ods", col_types = NA) %>%
  mutate_all(as.factor) %>%
  mutate(a_supprimer = as.logical(a_supprimer)) %>%
  select(variable, a_supprimer, variable_deb, lib_insee_long) %>% 
  distinct()
lib_var %>% select(variable, a_supprimer, lib_insee_long) %>% distinct() %>% 
  count(variable, a_supprimer) %>% filter(n > 1, !a_supprimer) 
# les éventuels doublons doivent être corrigé (une variable = un unique libellé) ou ne pas être importés (cas des variables des DOM)

# Vérification de la complétude de la documentation des variables "metadata/Insee_RGP_lgt_lib_variable.ods"
noms_var <- c(names(lgt_rp_actu ), names(lgt_rp_old ), names(lgt_rp_very_old )) %>% 
  unique %>% sort() %>% 
  setdiff(., c("annee", "CODGEO", "DEP", "LIBGEO", "REG")) 
all(noms_var %in% lib_var$variable_deb) # TRUE attendu
setdiff(lib_var$variable_deb, noms_var) # rien attendu (character(0))
setdiff(noms_var, lib_var$variable_deb) # rien attendu (character(0))


# calcul des variables ------
lgt_rp <- bind_rows(lgt_rp_actu, lgt_rp_old, lgt_rp_very_old) %>% 
  # mutate(RP_ACHTOT = coalesce(RP_ACHTT, RP_ACHTOT)) %>% 
  # select(-RP_ACHTT) %>%
  select(date = annee, depcom = CODGEO, everything(), -REG, -DEP, -LIBGEO) %>%
  pivot_longer(cols = -c(date, depcom), names_to = "variable_deb", values_to = "valeur") %>%
  left_join(lib_var, by = "variable_deb") %>%  
  # filter(is.na(variable)) %>% select(variable_deb) %>% distinct() #pour vérifier qu'il n'y a pas de nouvelles variables par rapport aux millésimes précédents
  filter(!a_supprimer) %>%
  select(-variable_deb, -a_supprimer) %>%
  mutate_if(is_character, as.factor) %>%
  mutate_if(is.factor, fct_drop) %>% 
  pivot_wider(id_cols = c(depcom, date), names_from = variable, values_from = valeur, values_fill = NA_real_) %>% 
  complete(depcom, date, fill = list(valeur = NA_real_)) %>% 
  mutate(date = make_date(as.character(date), 12, 31)) 

# on enlève les lignes communales Paris Lyon et Marseille si elles doublonnent les lignes d'arrondissement 
# (c'est le cas dans le csv a telecharger)
if(all(c("75056","75101") %in% lgt_rp$depcom)) {
  pop <-  filter(lgt_rp, !(depcom %in% c("75056", "13055", "69123")))
}


# versement dans le sgbd/datamart.portrait_territoires et documentation-------------
source("R/poster_documenter_data.R")
poster_documenter_it(df = lgt_rp, nom_table_sgbd = "source_lgt_rgp_insee", 
                     comm_source_en_plus = "doc INSEE disponible à https://www.insee.fr/fr/statistiques/7631186?sommaire=7631713")

rm(list=ls())
