
# ref_table_passage_territoire_sage

# librairies ------
library(datalibaba)
library(tidyverse)
library(sf)
library(mapview)
library(COGiter)
library(googlesheets4)

rm(list = ls())


# chargement SAGE ------------
n_sage_r52<-importer_data(db = "si_eau",
                          schema = "zonages_de_gestion",
                          table = "n_sage_r52") %>% 
  mutate(lb_etat=case_when(lb_etat=="Mis en oeuvre"~"mis_en_oeuvre",
                           lb_etat=="Élaboration"~"elaboration",
                           lb_etat=="Première révision"~"premiere_revision"))
# mapview(n_sage_r52,zol = c("nom"), color = "blue", alpha.regions = 0.5, legend = T)
# la couche géographique est de mauvaise qualité, car des limites de SAGE intersectent entre elles !


# limites administratives ----------
n_commune_exp_r52 <- importer_data(db = "referentiels",
                                   schema = "bdtopo_v3",
                                   table = "n_bdt_commune_s_r52") %>%
  select(code_insee, nom_com = nom_officiel)


# intersection communes ------------------
intersection_sage_communes <- st_intersection(st_buffer(n_sage_r52, 0), st_buffer(n_commune_exp_r52, 0)) %>% 
  mutate(surf_intersect = st_area(the_geom))

intersection_sage_communes2 <-intersection_sage_communes %>%
  st_drop_geometry() %>%
  select(code_insee,
         nom_com,
         nom_sage = nom, 
         code_sage = code, 
         etat_d_avancement_sage = lb_etat, 
         surf_intersect)

sage <- summarise(st_buffer(n_sage_r52, 0), do_union = TRUE)
# mapview(sage)

communes_hors_sage <- st_difference(st_buffer(n_commune_exp_r52, 0), st_buffer(sage, 0)) %>% 
  mutate(surf_intersect = st_area(the_geom))
communes_hors_sage$surf_intersect <- sort(communes_hors_sage$surf_intersect, decreasing = FALSE)
# mapview(communes_hors_sage)
# cette carte démontre la mauvaise qualité géométrique de la table n_sage_r52 

communes_hors_sage2 <- communes_hors_sage %>% 
  st_drop_geometry() %>% 
  mutate(nom_sage = "HORS SAGE",
         code_sage = "SAGE00000",
         etat_d_avancement_sage = "hors_sage",
         surf_intersect)
  
  
table_passage_territoire_sage <- bind_rows(intersection_sage_communes2,
                                    communes_hors_sage2) %>% 
  rename(DEPCOM = code_insee) %>% 
  select(-nom_com) %>% 
  cogifier(metro = FALSE) %>% 
  mutate_if(is.factor,as.character) %>% 
  mutate(date = as.Date("2022-06-01")) %>% 
  select(TypeZone, Zone, CodeZone, date, everything())


# versement de la table de passage et métadonnées ----------------
poster_data(data = table_passage_territoire_sage,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "ref_table_passage_territoire_sage",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone",  "date", "code_sage", "nom_sage"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(table_passage_territoire_sage), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  filter(source == nom_script_sce) %>% 
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "ref_table_passage_territoire_sage", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "ref_table_passage_territoire_sage", 
                user = "does")
