
# zz_captage_prioritaire_protection_action

# librairies ----------
library(tidyverse)
library(glue)
library(sf)
library(mefa4)
library(mapview)
library(rgdal)
library(readxl)
library(COGiter)
library(lubridate)
library(datalibaba)
library(googlesheets4)

rm(list=ls())


# limites administratives ----------
n_region_exp_r52<-importer_data(db = "referentiels",
                                schema = "adminexpress",
                                table = "n_region_exp_r52") %>% 
  select(insee_reg,nom_reg) %>%
  mutate(surf_region=st_area(the_geom))
  
n_departement_exp_r52<-importer_data(db = "referentiels",
                                     schema = "adminexpress",
                                     table = "n_departement_exp_r52") %>%
  select(insee_dep,nom) %>% 
  mutate(surf_departement=st_area(the_geom))

n_commune_exp_r52<-importer_data(db = "referentiels",
                                 schema = "adminexpress",
                                 table = "n_commune_exp_r52") %>%
  select(insee_com,nom,siren_epci) %>% 
  mutate(surf_commune=st_area(the_geom))

n_epci_zsup_r52<-importer_data(db = "consultation",
                               schema = "donnee_generique",
                               table = "n_epci_zsup_r52") %>%
  select(siren_epci,dep_epci,nom_epci) %>% 
  mutate(surf_epci=st_area(the_geom))


# listes communes, epci, départements et région Pays de la Loire -------

communes_pdl<-communes %>%
  filter(REG== '52') %>%
  select(DEPCOM,NOM_DEPCOM,EPCI) %>% 
  select(DEPCOM,NOM_DEPCOM) %>% 
  rename(CodeZone=DEPCOM,Zone=NOM_DEPCOM)

epci_pdl<-epci %>%
  unnest(REGIONS_DE_L_EPCI) %>%
  filter(REGIONS_DE_L_EPCI == '52') %>% 
  select(EPCI,NOM_EPCI) %>% 
  rename(CodeZone=EPCI,Zone=NOM_EPCI)

departements_pdl<-departements %>% 
  filter(REG=='52') %>% 
  select(DEP,NOM_DEP) %>% 
  rename(CodeZone=DEP,Zone=NOM_DEP)

region_pdl<-regions %>% 
  filter(REG=='52') %>% 
  select(REG,NOM_REG) %>% 
  rename(CodeZone=REG,Zone=NOM_REG)

territoire_pdl<-bind_rows(communes_pdl,
                          departements_pdl,
                          epci_pdl,
                          region_pdl) %>% 
  mutate_if(is.factor,as.character)


# stations, captages eau potable, captages prioritaires ------------
station<-importer_data(db = "si_eau",
                       schema = "stations",
                       table = "station")

captage_eau_potable_ars<-importer_data(db = "si_eau",
                       schema = "stations",
                       table = "captage_eau_potable_ars")

captage_eau_potable_ars<-right_join(station %>%
                                      select(code_station),
                                    captage_eau_potable_ars,
                                    by=c("code_station"="ins_code_national"))

station_captage_prioritaire<-importer_data(db = "si_eau",
                                       schema = "stations",
                                       table = "r_station_captage_prioritaire_r52")

station_captage_prioritaire<-station_captage_prioritaire %>% 
  select(code_station) %>% 
  mutate(code_station = as.character(code_station))

station_captage_prioritaire$code_station<- str_pad(station_captage_prioritaire$code_station, width = 9, pad = "0", side = "left")

# verif<-semi_join(station_captage_prioritaire %>%
#                    select(code_station) %>%
#                    st_drop_geometry(),
#                  captage_eau_potable_ars %>%
#                    select(code_station) %>%
#                    st_drop_geometry()) # 47 obs : c'est bon
# rm(verif)


# captages prioritaires et plan d'actions ---------

# selon srnp_dema courriel du 04/02/2021, les captages prioritaires ne possédant pas de Plan d'Actions sont :
# pour le 49 : la Rucette (049000394) ;le Longeron ;le Prieuré de la Madeleine (049000211) ;le Puits de la Fontaine Bourreau (049000479) ;
# pour le 85 : Sainte Germaine (085000184)

# le longeron est une ancienne commune, maintenant Sèvremoine
# en fait Barrage des rivières (049000402) http://www.maine-et-loire.gouv.fr/les-captages-prioritaires-grenelle-a6180.html

station_captage_prioritaire<-left_join(station_captage_prioritaire,
                                       station %>%
                                         st_drop_geometry() %>% 
                                         select(code_station,libelle_station)) %>% 
  mutate(plan_action=ifelse(code_station %notin% c("049000394","049000402","049000211","049000479","085000184"),"oui","non"))


# intersection captages prioritaires et territoires ---------                                       
intersection_captage_prioritaire_commune<-st_intersection(station_captage_prioritaire,st_buffer(n_commune_exp_r52,0))
# mapview(intersection_captage_prioritaire_commune,zcol=c("insee_com"),legend=F)+mapview(n_commune_exp_r52,alpha.regions=0)
intersection_captage_prioritaire_commune_2<-intersection_captage_prioritaire_commune %>% 
  st_drop_geometry() %>% 
  group_by(insee_com) %>% 
  mutate(nbre_captages_prioritaires=n()) %>% 
  ungroup() %>%
  select(insee_com,nbre_captages_prioritaires) %>% 
  unique() %>% 
  right_join(n_commune_exp_r52 %>% 
               select(insee_com) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires=ifelse(is.na(nbre_captages_prioritaires),0,nbre_captages_prioritaires)) %>% 
  mutate(TypeZone="Communes",variable="nbre_captages_prioritaires",date=today()) %>% 
  rename(CodeZone=insee_com,valeur=nbre_captages_prioritaires)

intersection_captage_prioritaire_epci<-st_intersection(station_captage_prioritaire,st_buffer(n_epci_zsup_r52,0))
# mapview(intersection_captage_prioritaire_epci,zcol=c("siren_epci"),legend=F)+mapview(n_epci_zsup_r52,alpha.regions=0)
intersection_captage_prioritaire_epci_2<-intersection_captage_prioritaire_epci %>% 
  st_drop_geometry() %>% 
  group_by(siren_epci) %>% 
  mutate(nbre_captages_prioritaires=n()) %>% 
  ungroup() %>%
  select(siren_epci,nbre_captages_prioritaires) %>% 
  unique() %>% 
  right_join(n_epci_zsup_r52 %>% 
               select(siren_epci) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires=ifelse(is.na(nbre_captages_prioritaires),0,nbre_captages_prioritaires)) %>% 
  mutate(TypeZone="Epci",variable="nbre_captages_prioritaires",date=today()) %>% 
  rename(CodeZone=siren_epci,valeur=nbre_captages_prioritaires)

intersection_captage_prioritaire_departement<-st_intersection(station_captage_prioritaire,st_buffer(n_departement_exp_r52,0))
# mapview(intersection_captage_prioritaire_departement,zcol=c("insee_dep"),legend=F)+mapview(n_departement_exp_r52,alpha.regions=0)
intersection_captage_prioritaire_departement_2<-intersection_captage_prioritaire_departement %>% 
  st_drop_geometry() %>% 
  group_by(insee_dep) %>% 
  mutate(nbre_captages_prioritaires=n()) %>% 
  ungroup() %>%
  select(insee_dep,nbre_captages_prioritaires) %>% 
  unique() %>% 
  right_join(n_departement_exp_r52 %>% 
               select(insee_dep) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires=ifelse(is.na(nbre_captages_prioritaires),0,nbre_captages_prioritaires)) %>% 
  mutate(TypeZone="Départements",variable="nbre_captages_prioritaires",date=today()) %>% 
  rename(CodeZone=insee_dep,valeur=nbre_captages_prioritaires)

intersection_captage_prioritaire_region<-st_intersection(station_captage_prioritaire,st_buffer(n_region_exp_r52,0))
# mapview(intersection_captage_prioritaire_region,zcol=c("insee_reg"),legend=F)+mapview(n_region_exp_r52,alpha.regions=0)
intersection_captage_prioritaire_region_2<-intersection_captage_prioritaire_region %>% 
  st_drop_geometry() %>%
  mutate(nbre_captages_prioritaires=n()) %>%
  select(insee_reg,nbre_captages_prioritaires)%>% 
  unique() %>% 
  mutate(TypeZone="Régions",variable="nbre_captages_prioritaires",date=today()) %>% 
  rename(CodeZone=insee_reg,valeur=nbre_captages_prioritaires)

intersection_captage_prioritaire_territoire<-bind_rows(intersection_captage_prioritaire_commune_2,
                                                       intersection_captage_prioritaire_epci_2,
                                                       intersection_captage_prioritaire_departement_2,
                                                       intersection_captage_prioritaire_region_2)
rm(intersection_captage_prioritaire_commune_2,
   intersection_captage_prioritaire_epci_2,
   intersection_captage_prioritaire_departement_2,
   intersection_captage_prioritaire_region_2)


# intersection captages prioritaires bénéficiant d'un plan d'actions et territoires -----------
plan_action_commune<-intersection_captage_prioritaire_commune %>% 
  st_drop_geometry() %>% 
  filter(plan_action=="oui") %>% 
  group_by(insee_com) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=n()) %>% 
  ungroup() %>%
  select(insee_com,nbre_captages_prioritaires_avec_plan_actions) %>% 
  unique() %>% 
  right_join(n_commune_exp_r52 %>% 
               select(insee_com) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=ifelse(is.na(nbre_captages_prioritaires_avec_plan_actions),0,nbre_captages_prioritaires_avec_plan_actions)) %>% 
  mutate(TypeZone="Communes",variable="nbre_captages_prioritaires_avec_plan_actions",date=today()) %>% 
  rename(CodeZone=insee_com,valeur=nbre_captages_prioritaires_avec_plan_actions)

plan_action_epci<-intersection_captage_prioritaire_epci %>% 
  st_drop_geometry() %>% 
  filter(plan_action=="oui") %>% 
  group_by(siren_epci) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=n()) %>% 
  ungroup() %>%
  select(siren_epci,nbre_captages_prioritaires_avec_plan_actions) %>% 
  unique() %>% 
  right_join(n_epci_zsup_r52 %>% 
               select(siren_epci) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=ifelse(is.na(nbre_captages_prioritaires_avec_plan_actions),0,nbre_captages_prioritaires_avec_plan_actions)) %>% 
  mutate(TypeZone="Epci",variable="nbre_captages_prioritaires_avec_plan_actions",date=today()) %>% 
  rename(CodeZone=siren_epci,valeur=nbre_captages_prioritaires_avec_plan_actions)

plan_action_departement<-intersection_captage_prioritaire_departement %>% 
  st_drop_geometry() %>% 
  filter(plan_action=="oui") %>% 
  group_by(insee_dep) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=n()) %>% 
  ungroup() %>%
  select(insee_dep,nbre_captages_prioritaires_avec_plan_actions) %>% 
  unique() %>% 
  right_join(n_departement_exp_r52 %>% 
               select(insee_dep) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_prioritaires_avec_plan_actions=ifelse(is.na(nbre_captages_prioritaires_avec_plan_actions),0,nbre_captages_prioritaires_avec_plan_actions)) %>% 
  mutate(TypeZone="Départements",variable="nbre_captages_prioritaires_avec_plan_actions",date=today()) %>% 
  rename(CodeZone=insee_dep,valeur=nbre_captages_prioritaires_avec_plan_actions)

plan_action_region<-intersection_captage_prioritaire_region %>% 
  st_drop_geometry() %>% 
  filter(plan_action=="oui") %>%
  mutate(nbre_captages_prioritaires_avec_plan_actions=n()) %>%
  select(insee_reg,nbre_captages_prioritaires_avec_plan_actions)%>% 
  unique() %>% 
  mutate(TypeZone="Régions",variable="nbre_captages_prioritaires_avec_plan_actions",date=today()) %>% 
  rename(CodeZone=insee_reg,valeur=nbre_captages_prioritaires_avec_plan_actions)

plan_action_territoire<-bind_rows(plan_action_commune,
                                  plan_action_epci,
                                  plan_action_departement,
                                  plan_action_region)
rm(plan_action_commune,
   plan_action_epci,
   plan_action_departement,
   plan_action_region)


# protection des captages --------------
# r_ppcaptages_s_r52<-st_read(dsn_si_eau,query = "SELECT * FROM eau_potable.r_ppcaptages_s_r52") # 890 obs
r_ppcaptages_s_r52<-importer_data(db = "si_eau",
                                        schema = "eau_potable",
                                        table = "r_ppcaptages_s_r52") # 878 obs
protection_captage<-summarise(st_buffer(r_ppcaptages_s_r52,0),do_union = TRUE)


# intersections captages et protections (ppe ou ppi_ppr) ---------
captage_protege<-st_intersection(protection_captage,captage_eau_potable_ars)


# intersection captages protégés et territoires ------
intersection_captage_protege_commune<-st_intersection(captage_protege,st_buffer(n_commune_exp_r52,0))
# mapview(intersection_captage_protege_commune,zcol=c("insee_com"),legend=F)+mapview(n_commune_exp_r52,alpha.regions=0)
intersection_captage_protege_commune_2<-intersection_captage_protege_commune %>% 
  st_drop_geometry() %>% 
  group_by(insee_com) %>% 
  mutate(nbre_captages_proteges=n()) %>% 
  ungroup() %>%
  select(insee_com,nbre_captages_proteges) %>% 
  unique() %>% 
  right_join(n_commune_exp_r52 %>% 
               select(insee_com) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_proteges=ifelse(is.na(nbre_captages_proteges),0,nbre_captages_proteges)) %>% 
  mutate(TypeZone="Communes",variable="nbre_captages_proteges",date=today()) %>% 
  rename(CodeZone=insee_com,valeur=nbre_captages_proteges)

intersection_captage_protege_epci<-st_intersection(captage_protege,st_buffer(n_epci_zsup_r52,0))
# mapview(intersection_captage_protege_epci,zcol=c("siren_epci"),legend=F)+mapview(n_epci_zsup_r52,alpha.regions=0)
intersection_captage_protege_epci_2<-intersection_captage_protege_epci %>% 
  st_drop_geometry() %>% 
  group_by(siren_epci) %>% 
  mutate(nbre_captages_proteges=n()) %>% 
  ungroup() %>%
  select(siren_epci,nbre_captages_proteges) %>% 
  unique() %>% 
  right_join(n_epci_zsup_r52 %>% 
               select(siren_epci) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_proteges=ifelse(is.na(nbre_captages_proteges),0,nbre_captages_proteges)) %>% 
  mutate(TypeZone="Epci",variable="nbre_captages_proteges",date=today()) %>% 
  rename(CodeZone=siren_epci,valeur=nbre_captages_proteges)

intersection_captage_protege_departement<-st_intersection(captage_protege,st_buffer(n_departement_exp_r52,0))
# mapview(intersection_captage_protege_departement,zcol=c("insee_dep"),legend=F)+mapview(n_departement_exp_r52,alpha.regions=0)
intersection_captage_protege_departement_2<-intersection_captage_protege_departement %>% 
  st_drop_geometry() %>% 
  group_by(insee_dep) %>% 
  mutate(nbre_captages_proteges=n()) %>% 
  ungroup() %>%
  select(insee_dep,nbre_captages_proteges) %>% 
  unique() %>% 
  right_join(n_departement_exp_r52 %>% 
               select(insee_dep) %>%
               st_drop_geometry()) %>% 
  mutate(nbre_captages_proteges=ifelse(is.na(nbre_captages_proteges),0,nbre_captages_proteges)) %>% 
  mutate(TypeZone="Départements",variable="nbre_captages_proteges",date=today()) %>% 
  rename(CodeZone=insee_dep,valeur=nbre_captages_proteges)

intersection_captage_protege_region<-st_intersection(captage_protege,st_buffer(n_region_exp_r52,0))
# mapview(intersection_captage_protege_region,zcol=c("insee_reg"),legend=F)+mapview(n_region_exp_r52,alpha.regions=0)
intersection_captage_protege_region_2<-intersection_captage_protege_region %>% 
  st_drop_geometry() %>%
  mutate(nbre_captages_proteges=n()) %>%
  select(insee_reg,nbre_captages_proteges)%>% 
  unique() %>% 
  mutate(TypeZone="Régions",variable="nbre_captages_proteges",date=today()) %>% 
  rename(CodeZone=insee_reg,valeur=nbre_captages_proteges)

intersection_captage_protege_territoire<-bind_rows(intersection_captage_protege_commune_2,
                                                   intersection_captage_protege_epci_2,
                                                   intersection_captage_protege_departement_2,
                                                   intersection_captage_protege_region_2)
rm(intersection_captage_protege_commune_2,
   intersection_captage_protege_epci_2,
   intersection_captage_protege_departement_2,
   intersection_captage_protege_region_2)


# intersection protection et territoires ----------
intersection_protection_captage_commune<-st_intersection(st_buffer(protection_captage,0),st_buffer(n_commune_exp_r52,0))
# mapview(intersection_protection_captage_commune,col.regions = "red")+mapview(n_commune_exp_r52,alpha.regions=0)
# la carte intersection_protection_captage_commune n'affiche aucun polygone
intersection_protection_captage_commune_2<-intersection_protection_captage_commune %>% 
  mutate(surf_protection_captage=st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(insee_com) %>% 
  mutate(part_protection_captage=round(surf_protection_captage/surf_commune*100,digits = 2)) %>% 
  ungroup() %>% 
  right_join(n_commune_exp_r52 %>% 
               select(insee_com) %>%
               st_drop_geometry()) %>% 
  select(insee_com,part_protection_captage) %>% 
  mutate(part_protection_captage=ifelse(is.na(part_protection_captage),0,part_protection_captage)) %>% 
  mutate(TypeZone="Communes",variable="part_protection_captage",date=today()) %>% 
  rename(CodeZone=insee_com,valeur=part_protection_captage)

intersection_protection_captage_epci<-st_intersection(st_buffer(protection_captage,0),st_buffer(n_epci_zsup_r52,0))
# mapview(intersection_protection_captage_epci)+mapview(n_epci_zsup_r52,alpha.regions=0)
# la carte intersection_protection_captage_epci n'affiche aucun polygone
intersection_protection_captage_epci_2<-intersection_protection_captage_epci %>% 
  mutate(surf_protection_captage=st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(siren_epci) %>% 
  mutate(part_protection_captage=round(surf_protection_captage/surf_epci*100,digits = 2)) %>% 
  ungroup() %>% 
  right_join(n_epci_zsup_r52 %>% 
               select(siren_epci,nom_epci) %>%
               st_drop_geometry()) %>% 
  select(siren_epci,part_protection_captage) %>% 
  mutate(part_protection_captage=ifelse(is.na(part_protection_captage),0,part_protection_captage)) %>% 
  mutate(TypeZone="Epci",variable="part_protection_captage",date=today()) %>% 
  rename(CodeZone=siren_epci,valeur=part_protection_captage)

intersection_protection_captage_departement<-st_intersection(st_buffer(protection_captage,0),st_buffer(n_departement_exp_r52,0))
# mapview(intersection_protection_captage_departement)+mapview(n_departement_exp_r52,alpha.regions=0)
intersection_protection_captage_departement_2<-intersection_protection_captage_departement %>% 
  mutate(surf_protection_captage = st_area(geom)) %>% 
  st_drop_geometry() %>% 
  group_by(insee_dep) %>% 
  mutate(part_protection_captage = round(surf_protection_captage/surf_departement*100,digits = 2)) %>% 
  ungroup() %>% 
  right_join(n_departement_exp_r52 %>% 
               select(insee_dep,nom) %>%
               st_drop_geometry()) %>% 
  select(insee_dep,part_protection_captage) %>% 
  mutate(part_protection_captage=ifelse(is.na(part_protection_captage),0,part_protection_captage)) %>% 
  mutate(TypeZone="Départements",variable="part_protection_captage",date=today()) %>% 
  rename(CodeZone=insee_dep,valeur=part_protection_captage)

intersection_protection_captage_region<-st_intersection(st_buffer(protection_captage,0),st_buffer(n_region_exp_r52,0))
# mapview(intersection_protection_captage_region)+mapview(n_region_exp_r52,alpha.regions=0)
intersection_protection_captage_region_2<-intersection_protection_captage_region %>% 
  mutate(surf_protection_captage=st_area(geom)) %>% 
  st_drop_geometry() %>%  
  mutate(part_protection_captage=round(surf_protection_captage/surf_region*100,digits = 2)) %>% 
  select(insee_reg,part_protection_captage) %>% 
  mutate(TypeZone="Régions",variable="part_protection_captage",date=today()) %>% 
  mutate(part_protection_captage=as.numeric(part_protection_captage)) %>% 
  rename(CodeZone=insee_reg,valeur=part_protection_captage)

intersection_protection_captage_territoire<-bind_rows(intersection_protection_captage_commune_2,
                                                      intersection_protection_captage_epci_2,
                                                      intersection_protection_captage_departement_2,
                                                      intersection_protection_captage_region_2)
rm(intersection_protection_captage_commune_2,
   intersection_protection_captage_epci_2,
   intersection_protection_captage_departement_2,
   intersection_protection_captage_region_2)


# assemblage ------------
specifique_captage_prioritaire_protection_action<-bind_rows(intersection_captage_protege_territoire,
                                                            intersection_protection_captage_territoire,
                                                            intersection_captage_prioritaire_territoire,
                                                            plan_action_territoire) %>%
  left_join(territoire_pdl) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone,CodeZone,Zone,date,variable,valeur) %>%
  pivot_wider(names_from = variable,values_from = valeur)


# # carte ------------
# mapview(n_region_exp_r52,alpha.regions=0,legend=F)+
#   mapview(r_ppcaptages_s_r52,col.regions="red")+
#   mapview(captage_eau_potable_ars)+
#   mapview(station_captage_prioritaire,col.regions="green",color="black")


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = specifique_captage_prioritaire_protection_action,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_captage_prioritaire_protection_action",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(specifique_captage_prioritaire_protection_action), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
      )
    )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_captage_prioritaire_protection_action", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_captage_prioritaire_protection_action", 
                user = "does")

