
# specifique_etat_ecologique_cours_eau

# librairies --------
library(readxl)
library(tidyverse)
library(datalibaba)
library(sf)
library(mapview)
library(COGiter)
library(googlesheets4)

rm(list = ls())


# chargement des données de l'Agence de l'eau Loire-Bretagne -------
# le fichier Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx a été récupéré sur le site de l'agence de l'eau Loire-Bretagne : 
# https://donnees-documents.eau-loire-bretagne.fr/home/donnees/etat-2017-cours-deau.html
# https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.92166786379235
# un 2e onglet a été créé, ne conservant que les données utiles et renommant les champs
# état écologique des masses d’eau superficielles, hors masse d'eau de transition et plans d'eau !
# état calculé avec les données 2015 à 2017

download.file(url = "https://donnees-documents.eau-loire-bretagne.fr/files/live/mounts/midas/Donnees-et-documents/Etat_Ecologique_cours_d_.92166786379235", 
              destfile = "extdata/Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx")
# attention, le fichier téléchargé par cette commande peut être corrompu et ne pas être lisible

etat_ecolo_cours_eau_2017<-read_excel(path = "extdata/Etat_Ecologique_cours_d_eau_2017_RESUME.xlsx",
                                      sheet="Etat Cours d'eau",
                                      skip = 5,
                                      col_names = TRUE)

etat_ecolo_cours_eau_2017<-etat_ecolo_cours_eau_2017 %>%
  select(code_masse_d_eau = `code de la masse d'eau`,
         nom_masse_d_eau = `Nom de la masse d'eau`,
         cours_d_eau = `Cours d'eau`,
         type_masse_d_eau = `Type de la masse d'eau`,
         type_FR_masse_d_eau = `Type_FR de la masse d'eau`,
         commision_territoriale = `commision territoriale`,
         SAGE,
         region_principale = `Region principale`,
         regions_concernees = `Région(s) concernée(s)`,
         departement_principal = `Département principal`,
         departements_concernes = `Département(s) concerné(s)`,
         etat_ecologique_valide = `État Écologique validé`,
         niveau_de_confiance_valide = `Niveau de confiance validé`,
         etat_ecologique_calcule = `État Écologique calculé`,
         etat_biologique = `État Biologique`,
         etat_physico_chimie_generale = `État physico-chimie générale`,
         etat_polluants_specifiques = `État Polluants spécifiques`,
         code_station_retenue_biologie_physico_chimie = `Station retenue...37`,
         libelle_station_biologie_physico_chimie = Libellé...38,
         code_station_retenue_polluants_specifiques = `Station retenue...39`,
         libelle_station_retenue_polluants_specifiques = Libellé...40)



n_masse_eau_bassin_versant_loire_bretagne <- importer_data(db = "si_eau",
                                                           schema = "hydrographie",
                                                           table = "n_masse_eau_bassin_versant_loire_bretagne")

etat_ecolo_cours_eau_2017_geo<-right_join(n_masse_eau_bassin_versant_loire_bretagne,
                                          etat_ecolo_cours_eau_2017 %>%
                                            select(code_masse_d_eau,
                                                   nom_masse_d_eau,SAGE,
                                                   etat_ecologique_valide),
                                          by=c("cd_eu_masse_eau"="code_masse_d_eau"))


# limites administratives ----------
n_region_exp_r52<-importer_data(db = "referentiels",
                                schema = "adminexpress",
                                table = "n_region_exp_r52") %>% 
  select(insee_reg,nom_reg) %>%
  mutate(surf_region=st_area(the_geom))

n_departement_exp_r52<-importer_data(db = "referentiels",
                                     schema = "adminexpress",
                                     table = "n_departement_exp_r52") %>%
  select(insee_dep,nom) %>% 
  rename(nom_dep = nom) %>% 
  mutate(surf_departement=st_area(the_geom))

n_commune_exp_r52<-importer_data(db = "referentiels",
                                 schema = "adminexpress",
                                 table = "n_commune_exp_r52") %>%
  select(insee_com,nom,siren_epci) %>% 
  rename(nom_com = nom) %>% 
  mutate(surf_commune=st_area(the_geom))

n_epci_zsup_r52<-importer_data(db = "consultation",
                               schema = "donnee_generique",
                               table = "n_epci_zsup_r52") %>%
  select(siren_epci,dep_epci,nom_epci) %>% 
  mutate(surf_epci=st_area(the_geom))


# intersection des bassins versants de masse d'eau et des communes -------------
etat_ecolo_cours_eau_2017_com<-st_intersection(st_buffer(etat_ecolo_cours_eau_2017_geo, 0),
                                                    st_buffer(n_commune_exp_r52, 0)) %>% 
  select(-c(superficie,shape_lenght,shape_area)) %>% 
  mutate(surf_me = st_area(the_geom))

# calcul de l'indicateur
# 1 :très bon ; 2 : bon ; 3 : moyen ; 4 : médiocre ; 5 : mauvais

indicateur_etat_ecolo_cours_eau_com <- etat_ecolo_cours_eau_2017_com %>% 
  st_drop_geometry() %>% 
  group_by(insee_com, nom_com) %>%
  mutate(surface_be_me = ifelse(etat_ecologique_valide<3, surf_me, 0)) %>% 
  summarise(surface_be_me = sum(surface_be_me), surf_commune = max(surf_commune)) %>% 
  mutate(indicateur = round(surface_be_me/surf_commune*100, digits = 1)) %>% 
  ungroup()

indicateur_etat_ecolo_cours_eau_com<-left_join(n_commune_exp_r52, indicateur_etat_ecolo_cours_eau_com) %>%
  select(-surf_commune) %>% 
  st_drop_geometry() %>% 
  mutate(indicateur = ifelse(is.na(indicateur), 0, indicateur)) %>% 
  mutate(TypeZone = "Communes", date = as.Date("2017-12-31"), variable = "part_cours_eau_bon_etat") %>% 
  rename(Zone = nom_com, CodeZone = insee_com, valeur = indicateur) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone, CodeZone, Zone, variable, valeur, date)


# intersection des bassins versants de masse d'eau et des EPCI -------------
etat_ecolo_cours_eau_2017_epci <- st_intersection(st_buffer(etat_ecolo_cours_eau_2017_geo, 0),
                                                      st_buffer(n_epci_zsup_r52, 0)) %>% 
  select(-c(superficie,shape_lenght,shape_area)) %>% 
  mutate(surf_me = st_area(the_geom))

# calcul de l'indicateur
# 1 :très bon ; 2 : bon ; 3 : moyen ; 4 : médiocre ; 5 : mauvais

indicateur_etat_ecolo_cours_eau_epci <- etat_ecolo_cours_eau_2017_epci %>% 
  st_drop_geometry() %>% 
  group_by(siren_epci, nom_epci) %>%
  mutate(surface_be_me = ifelse(etat_ecologique_valide<3, surf_me, 0)) %>% 
  summarise(surface_be_me = sum(surface_be_me), surf_epci = max(surf_epci)) %>% 
  mutate(indicateur = round(surface_be_me/surf_epci*100, digits = 1)) %>% 
  ungroup()

indicateur_etat_ecolo_cours_eau_epci<-left_join(n_epci_zsup_r52,indicateur_etat_ecolo_cours_eau_epci) %>%
  select(-surf_epci) %>% 
  st_drop_geometry() %>% 
  mutate(indicateur = ifelse(is.na(indicateur),0,indicateur)) %>% 
  mutate(TypeZone = "Epci",date = as.Date("2017-12-31"), variable = "part_cours_eau_bon_etat") %>% 
  rename(Zone = nom_epci,CodeZone = siren_epci, valeur = indicateur) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone,CodeZone,Zone,variable,valeur,date)


# intersection des bassins versants de masse d'eau et des départements ------------------
etat_ecolo_cours_eau_2017_dept <- st_intersection(st_buffer(etat_ecolo_cours_eau_2017_geo, 0),
                                                  st_buffer(n_departement_exp_r52, 0)) %>% 
  select(-c(superficie,shape_lenght,shape_area)) %>% 
  mutate(surf_me = st_area(the_geom))

# calcul de l'indicateur
# 1 :très bon ; 2 : bon ; 3 : moyen ; 4 : médiocre ; 5 : mauvais

indicateur_etat_ecolo_cours_eau_dept <- etat_ecolo_cours_eau_2017_dept %>% 
  st_drop_geometry() %>%
  group_by(insee_dep,nom_dep) %>% 
  mutate(surface_be_me = ifelse(etat_ecologique_valide<3, surf_me, 0)) %>% 
  summarise(surface_be_me = sum(surface_be_me), surf_departement = max(surf_departement)) %>% 
  mutate(indicateur = round(surface_be_me/surf_departement*100, digits = 1)) %>% 
  ungroup() %>% 
  select(insee_dep, nom_dep, indicateur) %>% 
  unique()

indicateur_etat_ecolo_cours_eau_dept<-left_join(n_departement_exp_r52, indicateur_etat_ecolo_cours_eau_dept) %>%
  select(-surf_departement) %>% 
  st_drop_geometry() %>% 
  mutate(indicateur = ifelse(is.na(indicateur), 0, indicateur)) %>% 
  mutate(TypeZone = "Départements", date = as.Date("2017-12-31"), variable = "part_cours_eau_bon_etat") %>% 
  rename(Zone = nom_dep, CodeZone = insee_dep, valeur = indicateur) %>% 
  mutate_if(is.character,as.factor) %>% 
  select(TypeZone, CodeZone, Zone, variable, valeur, date)


# intersection des bassins versants de masse d'eau et de la région
etat_ecolo_cours_eau_2017_region <- st_intersection(st_buffer(etat_ecolo_cours_eau_2017_geo, 0),
                                                    st_buffer(n_region_exp_r52, 0)) %>% 
  select(-c(superficie,shape_lenght, shape_area)) %>% 
  mutate(surf_me = st_area(the_geom))

# calcul de l'indicateur
# 1 :très bon ; 2 : bon ; 3 : moyen ; 4 : médiocre ; 5 : mauvais

indicateur_etat_ecolo_cours_eau_region <- etat_ecolo_cours_eau_2017_region %>% 
  st_drop_geometry() %>%
  filter(etat_ecologique_valide<3) %>% 
  mutate(indicateur = round(sum(surf_me)/surf_region*100, digits = 1)) %>%
  select(insee_reg, nom_reg, indicateur) %>% 
  unique()

indicateur_etat_ecolo_cours_eau_region <- left_join(n_region_exp_r52, indicateur_etat_ecolo_cours_eau_region) %>%
  select(-surf_region) %>% 
  st_drop_geometry() %>% 
  mutate(indicateur = ifelse(is.na(indicateur), 0, indicateur)) %>% 
  mutate(TypeZone = "Régions", date = as.Date("2017-12-31"), variable = "part_cours_eau_bon_etat") %>% 
  rename(Zone = nom_reg, CodeZone = insee_reg, valeur = indicateur) %>% 
  mutate_if(is.character, as.factor) %>% 
  select(TypeZone, CodeZone, Zone, variable, valeur, date)


# compilation communes, EPCI, départements, région ---------
indicateur_etat_ecolo_cours_eau<-bind_rows(indicateur_etat_ecolo_cours_eau_com,
                                           indicateur_etat_ecolo_cours_eau_epci,
                                           indicateur_etat_ecolo_cours_eau_dept,
                                           indicateur_etat_ecolo_cours_eau_region)

specifique_etat_ecolo_cours_eau<-pivot_wider(indicateur_etat_ecolo_cours_eau,
                                             names_from = variable,
                                             values_from = valeur)


# versement dans le sgbd/datamart.portrait_territoires -------------
poster_data(data = specifique_etat_ecolo_cours_eau,
            db = "datamart",
            schema = "portrait_territoires", 
            table = "specifique_etat_ecolo_cours_eau",
            post_row_name = FALSE, 
            overwrite = TRUE,
            droits_schema = TRUE,
            pk = c("TypeZone", "CodeZone", "Zone", "date"), # déclaration d'une clé primaire sur la table postée
            user = "does")


# METADONNEES------------------------------------

## On récupère la liste des variables qui sont à documenter dans le tableur google sheet à partir du jeu de données posté
var <- setdiff(names(specifique_etat_ecolo_cours_eau), c("TypeZone", "CodeZone", "Zone", "date"))

## récupération du nom du présent script source pour filtrer ensuite le référentiel des indicateurs
nom_script_sce <- rstudioapi::getActiveDocumentContext()$path %>% # utilisation de rstudioapi pour récupérer le nom du présent script 
  basename() %>% # on enlève le chemin d'accès pour ne garder que le nom du fichier
  gsub(pattern = ".R$", "", .) # on enlève l'extension '.R'

## authentification google sheet grâce au .Renviron
gs4_auth_configure(api_key = Sys.getenv("google_api_key"))
gs4_deauth()

## chargement du référentiel indicateurs google sheet
metadata_indicateur <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                                  sheet = "indicateurs") %>%
  # on ne garde que les variables concernées par le présent script de chargement
  filter(source == nom_script_sce) %>% 
  # on ajoute l'unité dans le libellé de la variable
  mutate(libelle_variable = paste0(libelle_variable, " (unit\u00e9 : ", unite, ")")) %>% 
  select(variable, libelle_variable) %>% 
  # ajout des libellés pour date
  bind_rows(
    tribble(
      ~variable, ~libelle_variable,
      "date", "Millesime"
    )
  )

## Vérification que la documentation des indicateurs est complète
all(var %in% metadata_indicateur$variable) # doit renvoyer TRUE

## Envoi des libellés de variable dans le SGBD
post_dico_attr(dico = metadata_indicateur, 
               table = "specifique_etat_ecolo_cours_eau", 
               schema = "portrait_territoires",
               db = "datamart",
               user = "does")

## Récupération des métadonnées de la source
nom_sce <- str_replace(nom_script_sce, "chargement_|ref_|specifique_", "") %>%
  str_replace("indicateur_", "") %>%
  str_replace("_cogiter|_cog$", "")

metadata_source <- read_sheet("https://docs.google.com/spreadsheets/d/1n-dhtrJM3JwFVz5WSEGOQzQ8A0G7VT_VcxDe5gh6zSo/edit#gid=60292277",
                              sheet = "sources") %>%
  filter(source == nom_sce) %>% 
  mutate(com_table = paste0(source_lib, " - ", producteur, ".\n", descriptif_sources)) %>% 
  pull(com_table)

## commentaires de la table
commenter_table(comment = metadata_source,
                db = "datamart",
                schema = "portrait_territoires",
                table = "specifique_etat_ecolo_cours_eau", 
                user = "does")
