
# chargement_agri

library(magrittr)

rm(list = ls())


# chargement des principaux résultats par commune du recensement agricole 2010 et ceux de celui de 2020----------------

# Au 02/01/2020, les données étaient téléchargeables sur le site Agreste recensement agricole 2010 
# (http://agreste.agriculture.gouv.fr/recensement-agricole-2010/resultats-donnees-chiffrees/)
# Le fichier : Donnees_principales_commune.zip
# Le fichier a été dézipé et simplifié à la main pour pouvoir être chargé dans R : agreste_ra_donnees_principales_commune.xls

# Mis à jour le 23 mai 2014 pour les recensements agricoles de 1988, 2000 et 2010 par commune : 
# selon les indications relevées le 06/02/2024 sur https://www.data.gouv.fr/fr/datasets/recensements-agricoles-par-communes-cors/

# Les principaux résultats chiffrés au format tableur des recensements agricoles 2010, 2000 et 1988 
# par département, canton et commune.
# Nombre d’exploitations, travail (en unité de travail annuel), superficie agricole utilisée (SAU), 
# superficie en terres labourables, en cultures permanentes, superficie toujours en herbe,
# Données sur le cheptel, les cultures et la main-d’oeuvre.
# Les données sont localisées à la commune du siège de l’exploitation
# En particulier, la SAU est celle des exploitations ayant leur siège dans la commune et non celle de la commune.

# Au 26/03/2021, selon le site data.gouv.fr, le jeu de données est non disponible (peut-être temporairement).
# (https://www.data.gouv.fr/fr/datasets/agreste-donnees-communales-resultats-des-recensements-agricoles-par-commune/)

# Au 07/06/2022, 
# un seul résultat pertinent sur le site de l'Agreste pour la requête "Recensements agricoles 2020" et catégorie "chiffres détaillés" :
# https://agreste.agriculture.gouv.fr/agreste-web/disaron/Recensement+agricole+2020/cda8b080-3e9e-4368-b41d-7a29c1da0be6/search/
# titre du tableau intéractif : "RA 2020 - 2010 Nombre d'exploitations, SAU, ETP, et PBS, par taille économique et par orientation"
# page de présentation :  https://agreste.agriculture.gouv.fr/agreste-web/disaron/RA2020_001/detail/ et bouton pour accéder au tableau
# la sélection de la communes comme dimension géographique génère un message d'erreur :
# "Votre requête ne peut aboutir. Si le tableau demandé est trop volumineux, merci d'en réduire la taille. 
# Si ce n'est pas le cas, merci de patienter quelques instants avant de relancer votre requête. N'hésitez pas à consulter l'aide en ligne."
# Via l’outil de cartographie Géoclip Air : https://stats.agriculture.gouv.fr/cartostat/#c=home, on arrive à télécharger un fichier data.xlsx,
# mais les variables disponibles se réduisent au nombre d'exploitations et la SAU par commune.

# Au 11/05/2023, la même chose qu'au 07/06/2022 : les variables disponibles se réduisent au nombre d'exploitations et la SAU par commune en 2020.

# Au 02/02/2024, le jeu de données "Agreste - Données communales - Résultats des recensements agricoles par commune" 
# sur data.gouv.fr est indisponible
# (https://www.data.gouv.fr/fr/datasets/agreste-donnees-communales-resultats-des-recensements-agricoles-par-commune/)
# Avec l’outil de cartographie Géoclip  (https://stats.agriculture.gouv.fr/cartostat/#c=home), 
# on arrive à télécharger un fichier data.xlsx, mais les variables disponibles se réduisent 
# au nombre d'exploitations, la SAU, le nombre d'unités gros bétail, la part des prairies permanentes dans la SAU
# et la part des cultures permanentes dans la SAU par commune en 2020.
# Certaine valeurs sont rensignées par la mention "N/A - secret statistique".
# Mailles disponibles 2020 : commune, département, région


# données 1988, 2000 et 2010 ----------
agreste_ra <- readxl::read_excel(path = "extdata/agreste_ra_donnees_principales_commune.xls") %>% 
  dplyr::select(-c(`Libellé de commune`, `Niveau géographique`, Région, Département, Modification)) %>%
  dplyr::rename(depcom = 'Code géographique') %>% 
  dplyr::mutate(depcom = as.factor(depcom)) %>%
  dplyr::mutate_if(is.character,as.numeric) 
  
exploitation <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("exploitation")) %>%
  tidyr::gather(key = "variable", value = "valeur", `exploitation 2010`:`exploitation 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable, 14, 17))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01", date, sep = "-"))) %>% 
  dplyr::mutate(variable = "nbre_exploitation") %>% 
  dplyr::mutate_if(is.character, as.factor)

uta <- agreste_ra %>%
  dplyr::select(depcom, tidyr::starts_with("uta")) %>%
  tidyr::gather(key = "variable",value = "valeur",`uta 2010`:`uta 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,5,8))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01", date, sep = "-"))) %>% 
  dplyr::mutate(variable = "unite_travail_annuel") %>% 
  dplyr::mutate_if(is.character,as.factor)

sau <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("sau")) %>%
  tidyr::gather(key = "variable",value = "valeur",`sau 2010`:`sau 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,5,8))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01", date, sep = "-"))) %>% 
  dplyr::mutate(variable = "superficie_agricole_utilisee_siege") %>% 
  dplyr::mutate_if(is.character,as.factor)

ugbta <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("ugbta")) %>%
  tidyr::gather(key = "variable",value = "valeur",`ugbta 2010`:`ugbta 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,7,10))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01",date,sep = "-"))) %>% 
  dplyr::mutate(variable = "unite_gros_betail_tous_aliments") %>% 
  dplyr::mutate_if(is.character,as.factor)

stl <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("stl")) %>%
  tidyr::gather(key = "variable",value = "valeur",`stl 2010`:`stl 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,5,8))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01",date,sep = "-"))) %>% 
  dplyr::mutate(variable = "superficie_terre_labourable") %>% 
  dplyr::mutate_if(is.character,as.factor)

scp <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("scp")) %>%
  tidyr::gather(key = "variable",value = "valeur",`scp 2010`:`scp 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,5,8))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01",date,sep = "-"))) %>% 
  dplyr::mutate(variable = "superficie_culture_permanente") %>% 
  dplyr::mutate_if(is.character,as.factor)

sth <- agreste_ra %>% 
  dplyr::select(depcom, tidyr::starts_with("sth")) %>%
  tidyr::gather(key = "variable",value = "valeur",`sth 2010`:`sth 1988`) %>%
  dplyr::mutate(date = as.numeric(stringr::str_sub(variable,5,8))) %>%
  dplyr::mutate(date = lubridate::dmy(paste("01-01",date,sep = "-"))) %>% 
  dplyr::mutate(variable = "superficie_toujours_en_herbe") %>% 
  dplyr::mutate_if(is.character,as.factor)

agri_1988_2000_2010 <- dplyr::bind_rows(
  exploitation, 
  uta, 
  sau, 
  ugbta, 
  stl, 
  scp, 
  sth
  ) %>% 
  dplyr::mutate_if(is.character, as.factor) %>%
  tidyr::complete(depcom, date, variable, fill = list(valeur = 0), explicit = FALSE) # 770364 obs

rm(agreste_ra, exploitation, uta, sau, ugbta, stl, scp,sth)


# complétude de la liste des communes pour les données 1988, 2000 et 2010 -------
liste_COG_2023 <- COGiter::communes %>%
  dplyr::select(depcom = DEPCOM) %>%
  dplyr::pull() %>% 
  as.character() # 34945 obs

agri_1988_2000_2010_2 <- agri_1988_2000_2010 %>% 
  tidyr::pivot_wider(names_from = variable, values_from = valeur) %>% 
  dplyr::mutate(depcom = forcats::fct_expand(depcom, liste_COG_2023)) %>% 
  tidyr::complete(depcom, date, fill = list(
    nbre_exploitation = 0,
    unite_travail_annuel = 0,
    superficie_agricole_utilisee_siege = 0,
    unite_gros_betail_tous_aliments = 0,
    superficie_terre_labourable = 0,
    superficie_culture_permanente = 0,
    superficie_toujours_en_herbe = 0
    )
  )
# liste_com_agri_1988_2000_2010_2 <- agri_1988_2000_2010_2 %>% dplyr::select(depcom) %>% unique() # 36708 obs


# # données 2020 (nbr exploitations et SAU uniquement) téléchargement via Geoclip du 11/05/2023 ---------
# agreste_ra_2020 <- openxlsx::read.xlsx(xlsxFile = "extdata/agreste_ra_2020_expl_sau_2023-05-11.xlsx", sheet = "Data" ) %>% 
#   dplyr::select(-'Libellé') %>% 
#   dplyr::rename(
#     depcom = Code,
#     superficie_agricole_utilisee_siege = 'SAU.en.2020',
#     nbre_exploitation = "Nombre.d'exploitations.en.2020"
#     ) %>% 
#   dplyr::mutate(date = lubridate::dmy(paste("01-01-2020"))) %>% 
#   dplyr::mutate(depcom = as.factor(depcom)) %>%
#   dplyr::mutate_if(is.integer, as.numeric) %>% 
#   tidyr::gather(key = "variable", value = "valeur", superficie_agricole_utilisee_siege:nbre_exploitation)


# données 2020 commune 2020 téléchargement via Geoclip du 02/02/2024 -------
agri_2020 <- openxlsx::read.xlsx(
  xlsxFile = "extdata/agreste_geoclip_ra_2020_2024-02-02_com.xlsx", 
  sheet = "Data", 
  startRow = 4 
  ) %>% 
  dplyr::select(
    depcom = Code,
    superficie_agricole_utilisee_siege = "SAU.en.2020",
    nbre_exploitation = "Nombre.d&apos;exploitations.en.2020",
    unite_gros_betail_tous_aliments = "Nombre.d&apos;UGB,.2020",
    part_prairie_permanente =  "Part.des.prairies.permanentes.dans.la.SAU,.2020",
    part_culture_permanente = "Part.des.cultures.permanentes.dans.la.SAU,.2020"
  ) %>% 
  dplyr::mutate(
    part_prairie_permanente = ifelse(part_prairie_permanente == "N/A - secret statistique", "NA", part_prairie_permanente),
    superficie_culture_permanente = part_culture_permanente*superficie_agricole_utilisee_siege/100,
    superficie_toujours_en_herbe = as.numeric(part_prairie_permanente)*superficie_agricole_utilisee_siege/100
  ) %>% 
  dplyr::mutate(date = as.Date("2020-01-01")) %>% 
  dplyr::select(depcom, date, tidyselect::everything()) %>% 
  dplyr::select(-part_prairie_permanente, -part_culture_permanente) %>% 
  tidyr::gather(key = "variable", value = "valeur", superficie_agricole_utilisee_siege:superficie_toujours_en_herbe) %>% 
  tidyr::complete(depcom, date, variable, fill = list(valeur = 0), explicit = FALSE)
# liste_com_agri_2020 <- agri_2020 %>% dplyr::select(depcom) %>% unique() # 34968 obs

agri_2020_2 <- agri_2020 %>% 
  tidyr::pivot_wider(names_from = variable, values_from = valeur) %>% 
  dplyr::mutate(depcom = forcats::fct_expand(depcom, liste_COG_2023)) %>% 
  tidyr::complete(depcom, date, fill = list(
    nbre_exploitation = 0,
    superficie_agricole_utilisee_siege = 0,
    unite_gros_betail_tous_aliments = 0,
    superficie_culture_permanente = 0,
    superficie_toujours_en_herbe = 0
  ))
# liste_com_agri_2020_2 <- agri_2020_2 %>% dplyr::select(depcom) %>% unique() # 34968 obs


# assemblage ------------
source_agri <- dplyr::bind_rows(
  agri_1988_2000_2010_2,
  agri_2020_2
)


# versement dans le sgbd/datamart.portrait_territoires et metadonnées -------------
source("R/poster_documenter_data.R", encoding = "UTF-8")
poster_documenter_it(
  df = source_agri ,
  nom_table_sgbd = "source_agri", 
  comm_source_en_plus = ""
  )

